@@ -2,7 +2,7 @@ package t::utilBabel;
 use t::util;
 use Carp;
 use Test::More;
-use Test::Deep qw(cmp_details deep_diag subbagof);
+use Test::Deep qw(cmp_details cmp_set deep_diag subbagof);
 use List::Util qw(min);
 use List::MoreUtils qw(uniq);
 use Hash::AutoHash::Args;
@@ -277,6 +277,7 @@ sub select_ur {
   }
   $table;
 }
+
 # NG 13-06-10: changed to do case insensitive comparisons
 sub filter_ur {
   my($table,$col,$ids)=@_;
@@ -683,8 +684,12 @@ QUERY
     report_fail(UNIVERSAL::isa($actual,$class),"$label object $i: class") or return 0;
     report_fail($actual->name eq $name,"$label object $i: name") or return 0;
     report_fail($actual->id eq $id,"$label object $i: id") or return 0;
-    report_fail(scrunched_eq($actual->inputs,$inputs),"$label object $i: inputs") or return 0;
-    report_fail(scrunched_eq($actual->namespace,$namespace),"$label object $i: namespace") or return 0;
+    # NG 13-06-12: compare as sets 'cuz perl 5.18 no longer preserves order
+    # report_fail(scrunched_eq($actual->inputs,$inputs),"$label object $i: inputs") or return 0;
+    report_fail(cmp_set(as_list($actual->inputs),as_list($inputs)),"$label object $i: inputs")
+      or return 0;
+    report_fail(scrunched_eq($actual->namespace,$namespace),"$label object $i: namespace") 
+      or return 0;
     report_fail(scrunched_eq($actual->query,$query),"$label object $i: query") or return 0;
     report_fail(as_bool($actual->view)==$view,"$label object $i: view") or return 0;
     report_fail(as_bool($actual->implicit)==$implicit,"$label object $i: implicit") or return 0;
@@ -719,8 +724,12 @@ QUERY
     report_fail(UNIVERSAL::isa($actual,$class),"$label object $i: class") or return 0;
     report_fail($actual->name eq $name,"$label object $i: name") or return 0;
     report_fail($actual->id eq $id,"$label object $i: id") or return 0;
-    report_fail(scrunched_eq($actual->inputs,$inputs),"$label object $i: inputs") or return 0;
-    report_fail(scrunched_eq($actual->namespace,"ConnectDots"),"$label object $i: namespace") or return 0;
+    # NG 13-06-12: compare as sets 'cuz perl 5.18 no longer preserves order
+    # report_fail(scrunched_eq($actual->inputs,$inputs),"$label object $i: inputs") or return 0;
+    report_fail(cmp_set(as_list($actual->inputs),as_list($inputs)),"$label object $i: inputs")
+      or return 0;
+    report_fail(scrunched_eq($actual->namespace,"ConnectDots"),"$label object $i: namespace") 
+      or return 0;
     report_fail(scrunched_eq($actual->query,$query),"$label object $i: query") or return 0;
      if ($mature) {
       check_object_basics($actual->babel,'Data::Babel','test',"$label object $i babel");
